////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  ica_2_0_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "ica_2_0_0.h"
#include "parametersetmanager.h"

ICA_2_0_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_calculate") == 0)
    {
        ParameterUtils::DoubleToString((double)opg_invalid_output_treatment_calculate, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_y") == 0)
    {
        ParameterUtils::DoubleToString((double)opg_invalid_output_treatment_y, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_cb") == 0)
    {
        ParameterUtils::DoubleToString((double)opg_invalid_output_treatment_cb, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_cr") == 0)
    {
        ParameterUtils::DoubleToString((double)opg_invalid_output_treatment_cr, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_valid") == 0)
    {
        ParameterUtils::DoubleToString((double)distorted_input_to_undistorted_ldc_grid_valid, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_valid") == 0)
    {
        ParameterUtils::DoubleToString((double)undistorted_to_lens_distorted_output_ld_grid_valid, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_ica20_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_calculate") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            opg_invalid_output_treatment_calculate = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_y") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            opg_invalid_output_treatment_y = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_cb") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            opg_invalid_output_treatment_cb = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_cr") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            opg_invalid_output_treatment_cr = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_valid") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            distorted_input_to_undistorted_ldc_grid_valid = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_valid") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            undistorted_to_lens_distorted_output_ld_grid_valid = (UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_ica20_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // opg_invalid_output_treatment_calculate
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("opg_invalid_output_treatment_calculate", ParameterParserDataType::UInt32, (double)opg_invalid_output_treatment_calculate, 0));
    }
    else if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_calculate") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)opg_invalid_output_treatment_calculate, 0));
    }

    // opg_invalid_output_treatment_y
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("opg_invalid_output_treatment_y", ParameterParserDataType::UInt32, (double)opg_invalid_output_treatment_y, 0));
    }
    else if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_y") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)opg_invalid_output_treatment_y, 0));
    }

    // opg_invalid_output_treatment_cb
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("opg_invalid_output_treatment_cb", ParameterParserDataType::UInt32, (double)opg_invalid_output_treatment_cb, 0));
    }
    else if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_cb") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)opg_invalid_output_treatment_cb, 0));
    }

    // opg_invalid_output_treatment_cr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("opg_invalid_output_treatment_cr", ParameterParserDataType::UInt32, (double)opg_invalid_output_treatment_cr, 0));
    }
    else if (PARAMETER_STRCMP(__name, "opg_invalid_output_treatment_cr") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)opg_invalid_output_treatment_cr, 0));
    }

    // distorted_input_to_undistorted_ldc_grid_valid
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("distorted_input_to_undistorted_ldc_grid_valid", ParameterParserDataType::UInt32, (double)distorted_input_to_undistorted_ldc_grid_valid, 0));
    }
    else if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_valid") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)distorted_input_to_undistorted_ldc_grid_valid, 0));
    }

    // undistorted_to_lens_distorted_output_ld_grid_valid
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("undistorted_to_lens_distorted_output_ld_grid_valid", ParameterParserDataType::UInt32, (double)undistorted_to_lens_distorted_output_ld_grid_valid, 0));
    }
    else if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_valid") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)undistorted_to_lens_distorted_output_ld_grid_valid, 0));
    }

    return __result;
}

bool ica20_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "y_interpolation_type") == 0)
    {
        ParameterUtils::DoubleToString((double)y_interpolation_type, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "ctc_grid_x_tab") == 0)
    {
        __result = ctc_grid_x_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "ctc_grid_y_tab") == 0)
    {
        __result = ctc_grid_y_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_0_tab") == 0)
    {
        __result = opg_interpolation_lut_0_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_1_tab") == 0)
    {
        __result = opg_interpolation_lut_1_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_2_tab") == 0)
    {
        __result = opg_interpolation_lut_2_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_x_tab") == 0)
    {
        __result = distorted_input_to_undistorted_ldc_grid_x_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_y_tab") == 0)
    {
        __result = distorted_input_to_undistorted_ldc_grid_y_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_x_tab") == 0)
    {
        __result = undistorted_to_lens_distorted_output_ld_grid_x_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_y_tab") == 0)
    {
        __result = undistorted_to_lens_distorted_output_ld_grid_y_tab.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool ica20_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "y_interpolation_type") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            y_interpolation_type = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "ctc_grid_x_tab") == 0)
    {
        __result = ctc_grid_x_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "ctc_grid_y_tab") == 0)
    {
        __result = ctc_grid_y_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_0_tab") == 0)
    {
        __result = opg_interpolation_lut_0_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_1_tab") == 0)
    {
        __result = opg_interpolation_lut_1_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_2_tab") == 0)
    {
        __result = opg_interpolation_lut_2_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_x_tab") == 0)
    {
        __result = distorted_input_to_undistorted_ldc_grid_x_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_y_tab") == 0)
    {
        __result = distorted_input_to_undistorted_ldc_grid_y_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_x_tab") == 0)
    {
        __result = undistorted_to_lens_distorted_output_ld_grid_x_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_y_tab") == 0)
    {
        __result = undistorted_to_lens_distorted_output_ld_grid_y_tab.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool ica20_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // y_interpolation_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("y_interpolation_type", ParameterParserDataType::UInt32, (double)y_interpolation_type, 0));
    }
    else if (PARAMETER_STRCMP(__name, "y_interpolation_type") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)y_interpolation_type, 0));
    }

    // ctc_grid_x_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ctc_grid_x_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ctc_grid_x_tab") == 0)
    {
        __result = ctc_grid_x_tab.GetInfo(&__path[__pos], __info);
    }

    // ctc_grid_y_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ctc_grid_y_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ctc_grid_y_tab") == 0)
    {
        __result = ctc_grid_y_tab.GetInfo(&__path[__pos], __info);
    }

    // opg_interpolation_lut_0_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("opg_interpolation_lut_0_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_0_tab") == 0)
    {
        __result = opg_interpolation_lut_0_tab.GetInfo(&__path[__pos], __info);
    }

    // opg_interpolation_lut_1_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("opg_interpolation_lut_1_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_1_tab") == 0)
    {
        __result = opg_interpolation_lut_1_tab.GetInfo(&__path[__pos], __info);
    }

    // opg_interpolation_lut_2_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("opg_interpolation_lut_2_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_2_tab") == 0)
    {
        __result = opg_interpolation_lut_2_tab.GetInfo(&__path[__pos], __info);
    }

    // distorted_input_to_undistorted_ldc_grid_x_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("distorted_input_to_undistorted_ldc_grid_x_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_x_tab") == 0)
    {
        __result = distorted_input_to_undistorted_ldc_grid_x_tab.GetInfo(&__path[__pos], __info);
    }

    // distorted_input_to_undistorted_ldc_grid_y_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("distorted_input_to_undistorted_ldc_grid_y_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_y_tab") == 0)
    {
        __result = distorted_input_to_undistorted_ldc_grid_y_tab.GetInfo(&__path[__pos], __info);
    }

    // undistorted_to_lens_distorted_output_ld_grid_x_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("undistorted_to_lens_distorted_output_ld_grid_x_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_x_tab") == 0)
    {
        __result = undistorted_to_lens_distorted_output_ld_grid_x_tab.GetInfo(&__path[__pos], __info);
    }

    // undistorted_to_lens_distorted_output_ld_grid_y_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("undistorted_to_lens_distorted_output_ld_grid_y_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_y_tab") == 0)
    {
        __result = undistorted_to_lens_distorted_output_ld_grid_y_tab.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool ica20_rgn_dataType::ctc_grid_x_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ctc_grid_x") == 0)
    {
        if (__index < 945)
        {
            ParameterUtils::DoubleToString((double)ctc_grid_x[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 945; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)ctc_grid_x[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::ctc_grid_x_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ctc_grid_x") == 0)
    {
        if (__index < 945)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                ctc_grid_x[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 945)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    ctc_grid_x[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::ctc_grid_x_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ctc_grid_x
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ctc_grid_x", ParameterParserDataType::Int32, true, false, 945));
    }

    return __result;
}

bool ica20_rgn_dataType::ctc_grid_y_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ctc_grid_y") == 0)
    {
        if (__index < 945)
        {
            ParameterUtils::DoubleToString((double)ctc_grid_y[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 945; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)ctc_grid_y[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::ctc_grid_y_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ctc_grid_y") == 0)
    {
        if (__index < 945)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                ctc_grid_y[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 945)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    ctc_grid_y[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::ctc_grid_y_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ctc_grid_y
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ctc_grid_y", ParameterParserDataType::Int32, true, false, 945));
    }

    return __result;
}

bool ica20_rgn_dataType::opg_interpolation_lut_0_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_0") == 0)
    {
        if (__index < 16)
        {
            ParameterUtils::DoubleToString((double)opg_interpolation_lut_0[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 16; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)opg_interpolation_lut_0[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::opg_interpolation_lut_0_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_0") == 0)
    {
        if (__index < 16)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                opg_interpolation_lut_0[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 16)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    opg_interpolation_lut_0[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::opg_interpolation_lut_0_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // opg_interpolation_lut_0
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("opg_interpolation_lut_0", ParameterParserDataType::Int32, true, false, 16));
    }

    return __result;
}

bool ica20_rgn_dataType::opg_interpolation_lut_1_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_1") == 0)
    {
        if (__index < 16)
        {
            ParameterUtils::DoubleToString((double)opg_interpolation_lut_1[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 16; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)opg_interpolation_lut_1[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::opg_interpolation_lut_1_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_1") == 0)
    {
        if (__index < 16)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                opg_interpolation_lut_1[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 16)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    opg_interpolation_lut_1[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::opg_interpolation_lut_1_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // opg_interpolation_lut_1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("opg_interpolation_lut_1", ParameterParserDataType::Int32, true, false, 16));
    }

    return __result;
}

bool ica20_rgn_dataType::opg_interpolation_lut_2_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_2") == 0)
    {
        if (__index < 16)
        {
            ParameterUtils::DoubleToString((double)opg_interpolation_lut_2[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 16; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)opg_interpolation_lut_2[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::opg_interpolation_lut_2_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "opg_interpolation_lut_2") == 0)
    {
        if (__index < 16)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                opg_interpolation_lut_2[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 16)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    opg_interpolation_lut_2[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::opg_interpolation_lut_2_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // opg_interpolation_lut_2
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("opg_interpolation_lut_2", ParameterParserDataType::Int32, true, false, 16));
    }

    return __result;
}

bool ica20_rgn_dataType::distorted_input_to_undistorted_ldc_grid_x_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_x") == 0)
    {
        if (__index < 945)
        {
            ParameterUtils::DoubleToString((double)distorted_input_to_undistorted_ldc_grid_x[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 945; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)distorted_input_to_undistorted_ldc_grid_x[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::distorted_input_to_undistorted_ldc_grid_x_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_x") == 0)
    {
        if (__index < 945)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                distorted_input_to_undistorted_ldc_grid_x[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 945)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    distorted_input_to_undistorted_ldc_grid_x[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::distorted_input_to_undistorted_ldc_grid_x_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // distorted_input_to_undistorted_ldc_grid_x
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("distorted_input_to_undistorted_ldc_grid_x", ParameterParserDataType::Int32, true, false, 945));
    }

    return __result;
}

bool ica20_rgn_dataType::distorted_input_to_undistorted_ldc_grid_y_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_y") == 0)
    {
        if (__index < 945)
        {
            ParameterUtils::DoubleToString((double)distorted_input_to_undistorted_ldc_grid_y[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 945; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)distorted_input_to_undistorted_ldc_grid_y[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::distorted_input_to_undistorted_ldc_grid_y_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "distorted_input_to_undistorted_ldc_grid_y") == 0)
    {
        if (__index < 945)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                distorted_input_to_undistorted_ldc_grid_y[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 945)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    distorted_input_to_undistorted_ldc_grid_y[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::distorted_input_to_undistorted_ldc_grid_y_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // distorted_input_to_undistorted_ldc_grid_y
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("distorted_input_to_undistorted_ldc_grid_y", ParameterParserDataType::Int32, true, false, 945));
    }

    return __result;
}

bool ica20_rgn_dataType::undistorted_to_lens_distorted_output_ld_grid_x_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_x") == 0)
    {
        if (__index < 945)
        {
            ParameterUtils::DoubleToString((double)undistorted_to_lens_distorted_output_ld_grid_x[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 945; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)undistorted_to_lens_distorted_output_ld_grid_x[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::undistorted_to_lens_distorted_output_ld_grid_x_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_x") == 0)
    {
        if (__index < 945)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                undistorted_to_lens_distorted_output_ld_grid_x[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 945)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    undistorted_to_lens_distorted_output_ld_grid_x[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::undistorted_to_lens_distorted_output_ld_grid_x_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // undistorted_to_lens_distorted_output_ld_grid_x
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("undistorted_to_lens_distorted_output_ld_grid_x", ParameterParserDataType::Int32, true, false, 945));
    }

    return __result;
}

bool ica20_rgn_dataType::undistorted_to_lens_distorted_output_ld_grid_y_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_y") == 0)
    {
        if (__index < 945)
        {
            ParameterUtils::DoubleToString((double)undistorted_to_lens_distorted_output_ld_grid_y[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 945; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)undistorted_to_lens_distorted_output_ld_grid_y[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::undistorted_to_lens_distorted_output_ld_grid_y_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "undistorted_to_lens_distorted_output_ld_grid_y") == 0)
    {
        if (__index < 945)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                undistorted_to_lens_distorted_output_ld_grid_y[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 945)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    undistorted_to_lens_distorted_output_ld_grid_y[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ica20_rgn_dataType::undistorted_to_lens_distorted_output_ld_grid_y_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // undistorted_to_lens_distorted_output_ld_grid_y
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("undistorted_to_lens_distorted_output_ld_grid_y", ParameterParserDataType::Int32, true, false, 945));
    }

    return __result;
}

bool mod_ica20_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "ica20_rgn_data") == 0)
    {
        __result = ica20_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_ica20_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "ica20_rgn_data") == 0)
    {
        __result = ica20_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_ica20_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // ica20_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ica20_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ica20_rgn_data") == 0)
    {
        __result = ica20_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_ica20_lens_zoom_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_zoom_trigger") == 0)
    {
        __result = lens_zoom_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_data") == 0)
    {
        __result = lens_zoom_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_ica20_lens_zoom_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_zoom_trigger") == 0)
    {
        __result = lens_zoom_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_data") == 0)
    {
        __result = lens_zoom_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_ica20_lens_zoom_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lens_zoom_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_zoom_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_trigger") == 0)
    {
        __result = lens_zoom_trigger.GetInfo(&__path[__pos], __info);
    }

    // lens_zoom_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_zoom_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_data") == 0)
    {
        __result = lens_zoom_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_ica20_lens_zoom_dataType::lens_zoom_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ica20_aec_data") == 0)
    {
        if (__index < mod_ica20_aec_dataCount)
        {
            __result = mod_ica20_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_ica20_lens_zoom_dataType::lens_zoom_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ica20_aec_data") == 0)
    {
        if (__index < mod_ica20_aec_dataCount)
        {
            __result = mod_ica20_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_ica20_lens_zoom_dataType::lens_zoom_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_ica20_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_ica20_aec_data", ParameterParserDataType::Structure, true, false, mod_ica20_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_ica20_aec_data") == 0)
    {
        if (__index < mod_ica20_aec_dataCount)
        {
            __result = mod_ica20_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_ica20_aec_dataCount));
        }
    }

    return __result;
}

bool mod_ica20_lens_posn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_posn_trigger") == 0)
    {
        __result = lens_posn_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_data") == 0)
    {
        __result = lens_posn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_ica20_lens_posn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_posn_trigger") == 0)
    {
        __result = lens_posn_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_data") == 0)
    {
        __result = lens_posn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_ica20_lens_posn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lens_posn_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_posn_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_trigger") == 0)
    {
        __result = lens_posn_trigger.GetInfo(&__path[__pos], __info);
    }

    // lens_posn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_posn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_data") == 0)
    {
        __result = lens_posn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_ica20_lens_posn_dataType::lens_posn_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ica20_lens_zoom_data") == 0)
    {
        if (__index < mod_ica20_lens_zoom_dataCount)
        {
            __result = mod_ica20_lens_zoom_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_ica20_lens_posn_dataType::lens_posn_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ica20_lens_zoom_data") == 0)
    {
        if (__index < mod_ica20_lens_zoom_dataCount)
        {
            __result = mod_ica20_lens_zoom_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_ica20_lens_posn_dataType::lens_posn_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_ica20_lens_zoom_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_ica20_lens_zoom_data", ParameterParserDataType::Structure, true, false, mod_ica20_lens_zoom_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_ica20_lens_zoom_data") == 0)
    {
        if (__index < mod_ica20_lens_zoom_dataCount)
        {
            __result = mod_ica20_lens_zoom_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_ica20_lens_zoom_dataCount));
        }
    }

    return __result;
}

bool chromatix_ica20_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ica20_lens_posn_data") == 0)
    {
        if (__index < mod_ica20_lens_posn_dataCount)
        {
            __result = mod_ica20_lens_posn_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_ica20_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ica20_lens_posn_data") == 0)
    {
        if (__index < mod_ica20_lens_posn_dataCount)
        {
            __result = mod_ica20_lens_posn_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_ica20_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_ica20_lens_posn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_ica20_lens_posn_data", ParameterParserDataType::Structure, true, false, mod_ica20_lens_posn_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_ica20_lens_posn_data") == 0)
    {
        if (__index < mod_ica20_lens_posn_dataCount)
        {
            __result = mod_ica20_lens_posn_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_ica20_lens_posn_dataCount));
        }
    }

    return __result;
}

bool chromatix_ica20Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ica20_reserve") == 0)
    {
        __result = chromatix_ica20_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ica20_core") == 0)
    {
        __result = chromatix_ica20_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_ica20Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ica20_reserve") == 0)
    {
        __result = chromatix_ica20_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ica20_core") == 0)
    {
        __result = chromatix_ica20_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_ica20Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_section
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_section", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetInfo(&__path[__pos], __info);
    }

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // chromatix_ica20_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_ica20_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ica20_reserve") == 0)
    {
        __result = chromatix_ica20_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_ica20_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_ica20_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ica20_core") == 0)
    {
        __result = chromatix_ica20_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_ica20Type::enable_sectionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ctc_transform_grid_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)ctc_transform_grid_enable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_ica20Type::enable_sectionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ctc_transform_grid_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ctc_transform_grid_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_ica20Type::enable_sectionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ctc_transform_grid_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ctc_transform_grid_enable", ParameterParserDataType::Int32, (double)ctc_transform_grid_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "ctc_transform_grid_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)ctc_transform_grid_enable, 0));
    }

    return __result;
}

bool chromatix_ica20Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_ica20Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_ica20Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_ica20Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_ica20Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_ica20Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_ica20Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 3)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 3; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ica20Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 3)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 3)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ica20Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 3));
    }

    return __result;
}

bool chromatix_ica20Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_ica20Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_ica20Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_ica20Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_ica20Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_ica20Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_ica20Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_ica20Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_ica20Type::control_variablesStruct::control_var_typeEnum::control_lens_position):
            enumValue = chromatix_ica20Type::control_variablesStruct::control_var_typeEnum::control_lens_position;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_ica20Type::control_variablesStruct::control_var_typeEnum::control_lens_zoom):
            enumValue = chromatix_ica20Type::control_variablesStruct::control_var_typeEnum::control_lens_zoom;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_ica20Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_ica20TypeClass::chromatix_ica20TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_ica20_reserve);
    PARAMETER_INITIALIZE(chromatix_ica20_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_ica20TypeClass::chromatix_ica20TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_ica20_reserve);
    PARAMETER_INITIALIZE(chromatix_ica20_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_ica20TypeClass::~chromatix_ica20TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_ica20TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "ica20_ife_module1")) == 0)
    {
        name = "ica20_ife_module1";
    }
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "ica20_ife_module2")) == 0)
    {
        name = "ica20_ife_module2";
    }
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "ica20_ipe_module1")) == 0)
    {
        name = "ica20_ipe_module1";
    }
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "ica20_ipe_module2")) == 0)
    {
        name = "ica20_ipe_module2";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_ica20_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(opg_invalid_output_treatment_calculate);
    PARAMETER_INITIALIZE(opg_invalid_output_treatment_y);
    PARAMETER_INITIALIZE(opg_invalid_output_treatment_cb);
    PARAMETER_INITIALIZE(opg_invalid_output_treatment_cr);
    PARAMETER_INITIALIZE(distorted_input_to_undistorted_ldc_grid_valid);
    PARAMETER_INITIALIZE(undistorted_to_lens_distorted_output_ld_grid_valid);

    SYMBOL_TABLE_ENTRY_READ(entry, result, opg_invalid_output_treatment_calculate, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, opg_invalid_output_treatment_y, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, opg_invalid_output_treatment_cb, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, opg_invalid_output_treatment_cr, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, distorted_input_to_undistorted_ldc_grid_valid, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, undistorted_to_lens_distorted_output_ld_grid_valid, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ica20_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ica20_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(y_interpolation_type);
    PARAMETER_INITIALIZE(ctc_grid_x_tab);
    PARAMETER_INITIALIZE(ctc_grid_y_tab);
    PARAMETER_INITIALIZE(opg_interpolation_lut_0_tab);
    PARAMETER_INITIALIZE(opg_interpolation_lut_1_tab);
    PARAMETER_INITIALIZE(opg_interpolation_lut_2_tab);
    PARAMETER_INITIALIZE(distorted_input_to_undistorted_ldc_grid_x_tab);
    PARAMETER_INITIALIZE(distorted_input_to_undistorted_ldc_grid_y_tab);
    PARAMETER_INITIALIZE(undistorted_to_lens_distorted_output_ld_grid_x_tab);
    PARAMETER_INITIALIZE(undistorted_to_lens_distorted_output_ld_grid_y_tab);

    SYMBOL_TABLE_ENTRY_READ(entry, result, y_interpolation_type, alignment)
    if (result)
    {
        result = ctc_grid_x_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = ctc_grid_y_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = opg_interpolation_lut_0_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = opg_interpolation_lut_1_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = opg_interpolation_lut_2_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = distorted_input_to_undistorted_ldc_grid_x_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = distorted_input_to_undistorted_ldc_grid_y_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = undistorted_to_lens_distorted_output_ld_grid_x_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = undistorted_to_lens_distorted_output_ld_grid_y_tab.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ica20_rgn_dataType_ctc_grid_x_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ica20_rgn_dataType::ctc_grid_x_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ctc_grid_x);

    result = entry->ReadArray(ctc_grid_x, 945, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ica20_rgn_dataType_ctc_grid_y_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ica20_rgn_dataType::ctc_grid_y_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ctc_grid_y);

    result = entry->ReadArray(ctc_grid_y, 945, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ica20_rgn_dataType_opg_interpolation_lut_0_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ica20_rgn_dataType::opg_interpolation_lut_0_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(opg_interpolation_lut_0);

    result = entry->ReadArray(opg_interpolation_lut_0, 16, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ica20_rgn_dataType_opg_interpolation_lut_1_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ica20_rgn_dataType::opg_interpolation_lut_1_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(opg_interpolation_lut_1);

    result = entry->ReadArray(opg_interpolation_lut_1, 16, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ica20_rgn_dataType_opg_interpolation_lut_2_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ica20_rgn_dataType::opg_interpolation_lut_2_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(opg_interpolation_lut_2);

    result = entry->ReadArray(opg_interpolation_lut_2, 16, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ica20_rgn_dataType_distorted_input_to_undistorted_ldc_grid_x_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ica20_rgn_dataType::distorted_input_to_undistorted_ldc_grid_x_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(distorted_input_to_undistorted_ldc_grid_x);

    result = entry->ReadArray(distorted_input_to_undistorted_ldc_grid_x, 945, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ica20_rgn_dataType_distorted_input_to_undistorted_ldc_grid_y_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ica20_rgn_dataType::distorted_input_to_undistorted_ldc_grid_y_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(distorted_input_to_undistorted_ldc_grid_y);

    result = entry->ReadArray(distorted_input_to_undistorted_ldc_grid_y, 945, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ica20_rgn_dataType_undistorted_to_lens_distorted_output_ld_grid_x_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ica20_rgn_dataType::undistorted_to_lens_distorted_output_ld_grid_x_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(undistorted_to_lens_distorted_output_ld_grid_x);

    result = entry->ReadArray(undistorted_to_lens_distorted_output_ld_grid_x, 945, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ica20_rgn_dataType_undistorted_to_lens_distorted_output_ld_grid_y_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ica20_rgn_dataType::undistorted_to_lens_distorted_output_ld_grid_y_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(undistorted_to_lens_distorted_output_ld_grid_y);

    result = entry->ReadArray(undistorted_to_lens_distorted_output_ld_grid_y, 945, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_ica20_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_ica20_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(ica20_rgn_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = ica20_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_ica20_lens_zoom_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_ica20_lens_zoom_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lens_zoom_trigger);
    PARAMETER_INITIALIZE(lens_zoom_data);

    result = lens_zoom_trigger.Load(entry, alignment);
    if (result)
    {
        result = lens_zoom_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_ica20_lens_zoom_dataType_lens_zoom_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_ica20_lens_zoom_dataType::lens_zoom_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_ica20_aec_data);


    // Reading Array mod_ica20_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_ica20_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_ica20_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_ica20_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_ica20_aec_dataDupInfo = pointerEntry->GetDupObject(mod_ica20_aec_dataCount, file, line);
            if (mod_ica20_aec_dataDupInfo != nullptr && mod_ica20_aec_dataDupInfo->Object != nullptr)
            {
                mod_ica20_aec_data = (mod_ica20_aec_dataType*)mod_ica20_aec_dataDupInfo->Object;
                if (mod_ica20_aec_data == nullptr)
                {
                    if (mod_ica20_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ica20_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_ica20_aec_dataDupInfo->File, mod_ica20_aec_dataDupInfo->Line, mod_ica20_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ica20_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_ica20_aec_dataDupInfo->Line, mod_ica20_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_ica20_aec_data == nullptr)
            {
                if (result && mod_ica20_aec_dataCount > 0)
                {
                    mod_ica20_aec_data = PARAMETER_NEW mod_ica20_aec_dataType[mod_ica20_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_ica20_aec_data, mod_ica20_aec_dataCount, file, line);
                }
                if (!result || mod_ica20_aec_data == nullptr)
                {
                    if (mod_ica20_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_ica20_aec_data\n");
                    }
                    mod_ica20_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_ica20_aec_dataCount; i++)
                {
                    result = mod_ica20_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_ica20_aec_data == nullptr)
        {
            mod_ica20_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_ica20_lens_posn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_ica20_lens_posn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lens_posn_trigger);
    PARAMETER_INITIALIZE(lens_posn_data);

    result = lens_posn_trigger.Load(entry, alignment);
    if (result)
    {
        result = lens_posn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_ica20_lens_posn_dataType_lens_posn_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_ica20_lens_posn_dataType::lens_posn_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_ica20_lens_zoom_data);


    // Reading Array mod_ica20_lens_zoom_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_ica20_lens_zoom_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_ica20_lens_zoom_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_ica20_lens_zoom_dataID = pointerEntry->ID;
            DupObjInfo* mod_ica20_lens_zoom_dataDupInfo = pointerEntry->GetDupObject(mod_ica20_lens_zoom_dataCount, file, line);
            if (mod_ica20_lens_zoom_dataDupInfo != nullptr && mod_ica20_lens_zoom_dataDupInfo->Object != nullptr)
            {
                mod_ica20_lens_zoom_data = (mod_ica20_lens_zoom_dataType*)mod_ica20_lens_zoom_dataDupInfo->Object;
                if (mod_ica20_lens_zoom_data == nullptr)
                {
                    if (mod_ica20_lens_zoom_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ica20_lens_zoom_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_ica20_lens_zoom_dataDupInfo->File, mod_ica20_lens_zoom_dataDupInfo->Line, mod_ica20_lens_zoom_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ica20_lens_zoom_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_ica20_lens_zoom_dataDupInfo->Line, mod_ica20_lens_zoom_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_ica20_lens_zoom_data == nullptr)
            {
                if (result && mod_ica20_lens_zoom_dataCount > 0)
                {
                    mod_ica20_lens_zoom_data = PARAMETER_NEW mod_ica20_lens_zoom_dataType[mod_ica20_lens_zoom_dataCount];
                    (void)pointerEntry->SetDupObject(mod_ica20_lens_zoom_data, mod_ica20_lens_zoom_dataCount, file, line);
                }
                if (!result || mod_ica20_lens_zoom_data == nullptr)
                {
                    if (mod_ica20_lens_zoom_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_ica20_lens_zoom_data\n");
                    }
                    mod_ica20_lens_zoom_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_ica20_lens_zoom_dataCount; i++)
                {
                    result = mod_ica20_lens_zoom_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_ica20_lens_zoom_data == nullptr)
        {
            mod_ica20_lens_zoom_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_ica20_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_ica20_lens_posn_data);


    // Reading Array mod_ica20_lens_posn_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_ica20_lens_posn_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_ica20_lens_posn_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_ica20_lens_posn_dataID = pointerEntry->ID;
            DupObjInfo* mod_ica20_lens_posn_dataDupInfo = pointerEntry->GetDupObject(mod_ica20_lens_posn_dataCount, file, line);
            if (mod_ica20_lens_posn_dataDupInfo != nullptr && mod_ica20_lens_posn_dataDupInfo->Object != nullptr)
            {
                mod_ica20_lens_posn_data = (mod_ica20_lens_posn_dataType*)mod_ica20_lens_posn_dataDupInfo->Object;
                if (mod_ica20_lens_posn_data == nullptr)
                {
                    if (mod_ica20_lens_posn_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ica20_lens_posn_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_ica20_lens_posn_dataDupInfo->File, mod_ica20_lens_posn_dataDupInfo->Line, mod_ica20_lens_posn_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ica20_lens_posn_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_ica20_lens_posn_dataDupInfo->Line, mod_ica20_lens_posn_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_ica20_lens_posn_data == nullptr)
            {
                if (result && mod_ica20_lens_posn_dataCount > 0)
                {
                    mod_ica20_lens_posn_data = PARAMETER_NEW mod_ica20_lens_posn_dataType[mod_ica20_lens_posn_dataCount];
                    (void)pointerEntry->SetDupObject(mod_ica20_lens_posn_data, mod_ica20_lens_posn_dataCount, file, line);
                }
                if (!result || mod_ica20_lens_posn_data == nullptr)
                {
                    if (mod_ica20_lens_posn_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_ica20_lens_posn_data\n");
                    }
                    mod_ica20_lens_posn_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_ica20_lens_posn_dataCount; i++)
                {
                    result = mod_ica20_lens_posn_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_ica20_lens_posn_data == nullptr)
        {
            mod_ica20_lens_posn_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_ica20Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_ica20_reserve);
    PARAMETER_INITIALIZE(chromatix_ica20_core);

    result = enable_section.Load(entry, alignment);
    if (result)
    {
        result = module_version.Load(entry, alignment);
    }
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_ica20_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_ica20_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load enable_sectionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20Type::enable_sectionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ctc_transform_grid_enable);

    SYMBOL_TABLE_ENTRY_READ(entry, result, ctc_transform_grid_enable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 3; i++)
    {
        result = chromatix_ica20Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_ica20_lens_zoom_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_ica20_lens_zoom_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    lens_zoom_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_ica20_lens_zoom_dataType_lens_zoom_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_ica20_lens_zoom_dataType::lens_zoom_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_ica20_aec_data))
    {
        PARAMETER_DELETE[] mod_ica20_aec_data;
    }
    mod_ica20_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_ica20_lens_posn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_ica20_lens_posn_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    lens_posn_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_ica20_lens_posn_dataType_lens_posn_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_ica20_lens_posn_dataType::lens_posn_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_ica20_lens_zoom_dataCount; i++)
    {
        mod_ica20_lens_zoom_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_ica20_lens_zoom_data))
    {
        PARAMETER_DELETE[] mod_ica20_lens_zoom_data;
    }
    mod_ica20_lens_zoom_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_ica20_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ica20_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_ica20_lens_posn_dataCount; i++)
    {
        mod_ica20_lens_posn_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_ica20_lens_posn_data))
    {
        PARAMETER_DELETE[] mod_ica20_lens_posn_data;
    }
    mod_ica20_lens_posn_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_ica20Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ica20Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_ica20_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ica20Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ica20Type::Release()
{
    ((chromatix_ica20TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_ica20Type::GetModified()
{
    return ((chromatix_ica20TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_ica20TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_ica20TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_ica20TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_ica20TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_ica20TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_ica20TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ica20TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_ica20TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_ica20TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ica20TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ica20TypeClass::Release()
{
    ParameterModule::Release();
}

ICA_2_0_0_NAMESPACE_END
